<?php
/**
 * domenatwo functions and definitions
 *
 * @package domenatwo
 */

define( 'LIVE_PREVIEW', false ); //turn demo mode on / off

$arDomainConfig = array(); //will be defined via domenatwo_setup();

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1040; /* pixels */
}

if ( ! function_exists( 'domenatwo_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function domenatwo_setup() {
	global $theme_options, $arDomainConfig;

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on domenatwo, use a find and replace
	 * to change 'domenatwo' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'domenatwo', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'footer' => __( 'فهرست فوتر', 'domenatwo' ),
	) );

	/**
	* Set domain settings
	*/
	$arDomainConfig = domenatwo_get_config_by_domain($_SERVER['HTTP_HOST']);
}
endif; // domenatwo_setup
add_action( 'after_setup_theme', 'domenatwo_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function domenatwo_widgets_init() {
	register_sidebar( array(
		'name' => __( 'ابزارک سمت چپ فوتر', 'domenatwo' ),
		'id' => 'footer-widget-left',
		'description' => __( 'This is the widget that displays to the left in the footer.', 'domenatwo' ),
		'before_widget' => '<div class="widget-instance">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widget-title">',
		'after_title' => '</h5>',
	) );

	// Area 2, located below the Primary Widget Area in the sidebar. Empty by default.
	register_sidebar( array(
		'name' => __( 'ابزارک وسط فوتر', 'domenatwo' ),
		'id' => 'footer-widget-center',
		'description' => __( 'This is the widget that displays to the center in the footer.', 'domenatwo' ),
		'before_widget' => '<div class="widget-instance">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widget-title">',
		'after_title' => '</h5>',
	) );

	// Area 3, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'ابزارک سمت راست فوتر', 'domenatwo' ),
		'id' => 'footer-widget-right',
		'description' => __( 'This is the widget that displays to the right in the footer.', 'domenatwo' ),
		'before_widget' => '<div class="widget-instance">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widget-title">',
		'after_title' => '</h5>',
	) );
}
add_action( 'widgets_init', 'domenatwo_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function domenatwo_scripts() {
	global $wp_customize;

	wp_enqueue_style( 'domenatwo-style', get_stylesheet_uri() );
	
	wp_enqueue_style( 'domenatwo-google-fonts', '//fonts.googleapis.com/css?family=Montserrat:400,700|Open+Sans:400,600' );

	wp_enqueue_script( 'domenatwo-modernizr', get_template_directory_uri() . '/js/vendor/modernizr-2.6.2.min.js', false, false, false);
	wp_enqueue_script( 'domenatwo-fittext', get_template_directory_uri() . '/js/vendor/jquery.fittext.js', array('jquery'), false, true );

	if($wp_customize) {
		wp_enqueue_style( 'domenatwo-customize-toolbar', get_template_directory_uri() . '/customize-toolbar.css' );
	}

	if(LIVE_PREVIEW) {
		wp_enqueue_style( 'domenatwo-live-preview-style', get_template_directory_uri() . '/live-preview-toolbar.css' );
		wp_enqueue_script( 'domenatwo-live-preview', get_template_directory_uri() . '/js/demo-live-preview.js', array('jquery'), false, true );
	}

	wp_enqueue_script( 'domenatwo-main', get_template_directory_uri() . '/js/main.js', array( 'jquery' ), false, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'domenatwo_scripts' );

/**
 * Determine home URL
 */
function domenatwo_get_home_url() {
	$blog_url = get_home_url();

	if(!strpos($blog_url, $_SERVER['HTTP_HOST'])) {
		$blog_url = '//' . $_SERVER['HTTP_HOST'];
	}

	return $blog_url;
}


/**
 * Get options / config for the current domaim
 */
function domenatwo_get_config_by_domain($domain) {
	$config = domenatwo_get_all_domain_configs();
	$domain = str_replace('www.', null, $_SERVER['HTTP_HOST']);

	if(isset($config[$domain])) {
		
		if(LIVE_PREVIEW) {
			$config[$domain]['domain_name'] = 'YourDomain.com';
		}

		return $config[$domain];

	}else{
		return domenatwo_get_default_domain_config($domain);
	}
}

/**
 * Get options / config for all domains
 */
function domenatwo_get_all_domain_configs() {
	$theme_options 	= thsp_cbp_get_options_values();
	$result			= array();

	if(!empty($theme_options['domain_list'])) {
		$arDomains		= explode('|', $theme_options['domain_list']);
		$options		= get_option('domenatwo_domain_config');

		foreach($arDomains as $domain) {
			$domain_key = strtolower($domain);

			if(!isset($options[$domain_key])) {
				//this domain has no settings - create defaults
				$result[$domain_key] = domenatwo_get_default_domain_config($domain);

			}else{
				$result[$domain_key] = $options[$domain_key];
			}
		}
	}

	return $result;
}

/**
 * Define default options for new domains
 */
function domenatwo_get_default_domain_config($domain = '') {
	$pages = get_posts(array(
		'post_type' => 'page',
		'meta_key' => '_wp_page_template',
		'meta_value' => 'template-lead-form.php'
	));

	$offer_button_link = '#';

	if(!empty($pages)) {
		$lead_page = reset($pages);
		$url 	   = get_permalink($lead_page->ID);
		$offer_button_link = domenatwo_convert_url($url);
	}

	return array(
		'page_title' => 'فروشی',
		'page_id' => '',
		'color_scheme_elements' => 'Blue',
		'color_scheme_main' => 'Light',
		'price_original' => '',
		'price_discount' => '',
		'price_button_text' => '',
		'price_button_link' => '',
		'offer_button_text' => 'پیشنهاد بدهید',
		'offer_button_link' => $offer_button_link,
		'domain_name' => $domain,
		'gai_profile_id' => '',
		'gai_time_period' => '30'
	);
}


/**
 * Gets the correct, relative URL for the current domain
 */
function domenatwo_convert_url($url) {
	$blog_url = get_bloginfo('url');

	if(!strpos($blog_url, $_SERVER['HTTP_HOST'])) {
		$url = str_replace(get_bloginfo('url'), "", $url);
	}

	return $url;
}


/**
 * Navigation Walker
 */
class domenatwo_footer_nav_walker extends Walker_Nav_Menu {
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="'. esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names;
		$output .= '>';

		$href = domenatwo_convert_url($item->url);

		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $href ) .'"' : '';

		$item_output  = '<a'. $attributes .'>';
		$item_output .= apply_filters( 'the_title', $item->title, $item->ID ) ;
		$item_output .= '</a>';

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}


/**
 * Disable admin bar when live preview is enabled
 */
if(LIVE_PREVIEW) {
	add_filter('show_admin_bar', '__return_false');
}


/**
 * Add domain name to lead form
 */
function domenatwo_add_domain_to_contact_form() {
	global $arDomainConfig;
	return $arDomainConfig['domain_name'];
}
add_filter( 'wpcf7_hidden_field_value', 'domenatwo_add_domain_to_contact_form');


/**
 * Fix wpautop
 * http://wordpress.org/support/topic/getting-shortcodes-with-content-to-play-nice-with-wpautop
 */
add_filter( 'the_content', 'wpautop',20 );


/**
 * Register the required plugins for this theme.
 *
 */
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';

function domenatwo_register_required_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		array(
			'name' 				=> 'Contact Form 7',
			'slug' 				=> 'contact-form-7',
			'required' 			=> true,
			'force_activation' 	=> true
		),

		array(
			'name' 				=> 'Contact Form 7 Modules',
			'slug' 				=> 'contact-form-7-modules',
			'required' 			=> true,
			'force_activation' 	=> true
		),

		array(
			'name'     				=> 'Symple Shortcodes', // The plugin name
			'slug'     				=> 'symple-shortcodes', // The plugin slug (typically the folder name)
			'source'   				=> get_stylesheet_directory() . '/plugins/symple-shortcodes.zip', // The plugin source
			'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
			'version' 				=> '1.4', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
			'force_activation' 		=> true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' 	=> true, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
		),

		array(
			'name' 				=> 'Widget Importer & Exporter',
			'slug' 				=> 'widget-importer-exporter',
			'required' 			=> true,
			'force_activation' 	=> true
		),

		array(
			'name' 				=> 'Wordpress Importer',
			'slug' 				=> 'wordpress-importer',
			'required' 			=> true,
			'force_activation' 	=> true
		),

		array(
			'name' 		=> 'Responsive Video Shortcodes',
			'slug' 		=> 'responsive-video-shortcodes',
			'required' 	=> false,
		)
	);

	// Used for internationalising strings
	$theme_text_domain = 'domenatwo';

	$config = array(
		'domain'       		=> $theme_text_domain,         	// Text domain - likely want to be the same as your theme.
		'default_path' 		=> '',                         	// Default absolute path to pre-packaged plugins
		'parent_menu_slug' 	=> 'themes.php', 				// Default parent menu slug
		'parent_url_slug' 	=> 'themes.php', 				// Default parent URL slug
		'menu'         		=> 'install-required-plugins', 	// Menu slug
		'has_notices'      	=> true,                       	// Show admin notices or not
		'is_automatic'    	=> false,					   	// Automatically activate plugins after installation or not
		'message' 			=> '',							// Message to output right before the plugins table
		'strings'      		=> array(
			'page_title'                       			=> __( 'نصب افزونه های مورد نیاز', $theme_text_domain ),
			'menu_title'                       			=> __( 'نصب افزونه ها', $theme_text_domain ),
			'installing'                       			=> __( 'نصب کردن افزونه: %s', $theme_text_domain ), // %1$s = plugin name
			'oops'                             			=> __( 'Something went wrong with the plugin API.', $theme_text_domain ),
			'notice_can_install_required'     			=> _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'			=> _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_install'  					=> _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
			'notice_can_activate_required'    			=> _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended'			=> _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_activate' 					=> _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
			'notice_ask_to_update' 						=> _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_update' 						=> _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
			'install_link' 					  			=> _n_noop( 'شروع نصب پلاگین', 'Begin installing plugins' ),
			'activate_link' 				  			=> _n_noop( 'فعال کردن پلاگین', 'Activate installed plugins' ),
			'return'                           			=> __( 'بازگشت به صفحه افزونه های مورد نیاز', $theme_text_domain ),
			'plugin_activated'                 			=> __( 'پلاگین با موفقیت فعال شد', $theme_text_domain ),
			'complete' 									=> __( 'همه ی پلاگین ها به خوبی نصب و فعال شدند %s', $theme_text_domain ), // %1$s = dashboard link
			'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );

}
add_action( 'tgmpa_register', 'domenatwo_register_required_plugins' );

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/theme-options.php';

/**
 * Load One-Click Install
 */
require get_template_directory() . '/inc/importer/importer-admin.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Widgets
 */
require get_template_directory() . '/inc/twitter/widget-latest-tweets.php';
require get_template_directory() . '/inc/widget-my-domains.php';

/**
 * Load Google Analytics
 */
require get_template_directory() . '/inc/google-analytics/ga.php';

/**
 * Load Shortcodes
 */
require get_template_directory() . '/inc/shortcodes.php';