<?php
/**
 * Google Analytics admin functions
 * Configures and authenticates with the Google Analytics API
 * @author Andrew Kallemeyn <ak@vective.co>
 */
 
 

/**
 * Open admin page with header and message
 */
function google_analytics_admin_render_header( $subheader, $css = '' ){
    ?>
     <div class="wrap">
        <h2><?php echo esc_html__('Google Analytics Settings', 'domenatwo')?></h2>
        <div class="<?php echo $css?>">
            <h3><?php echo esc_html($subheader)?></h3>
        </div>
    <?php
} 



/**
 * Close admin page
 */
function google_analytics_admin_render_footer(){
    ?>
    </div>
    <?php
}



/**
 * Render Google Analytics login link / info
 */
function google_analytics_admin_render_login() {
    $itemsFeedURL = "https://www.google.com/analytics/feeds/";
    $next_url  = home_url();
    $redirect_url = 'https://www.google.com/accounts/AuthSubRequest?session=1';
    $redirect_url .= '&next=';
    $redirect_url .= urlencode($next_url);
    $redirect_url .= "&scope=";
    $redirect_url .= urlencode($itemsFeedURL);

    echo '<div id="google_login">';
        echo '<a href="'.$redirect_url.'" class="button-primary action">' . __('Sign in to Google', 'domenatwo') . '</a>';
        echo '<p class="disclaimer">';
        echo __('We take your privacy seriously - we do not store your account information.', 'domenatwo');
        echo '<br /><br />';
        echo '<strong>' . __('Before using Google Analytics, you might need to', 'domenatwo');
        echo ' <a href="https://accounts.google.com/ManageDomains">' . __('verify your domain', 'domenatwo') . '</a> ' . __('with Google', 'domenatwo') . '.</strong> ' . __('Please read the documentation for more information. When asked "Target URL path prefix", provide this URL:', 'domenatwo') . '<br />';
        echo $next_url;
        echo '</p>';
    echo '</div>';
}
 


/**
 * Render account data
 */
function google_analytics_admin_render_account_data($data) {
    echo '<p><a href="'.admin_url('customize.php#google-analytics').'" class="button-primary action">' . __('Get Started Using Google Analytics', 'domenatwo') . '</a></p>';
    echo '<p>' . __('Need stats from a different Google account?', 'domenatwo') . ' <a href="' . admin_url('options-general.php?page=ga-admin&destroyToken=1') . '">' . __('Logout', 'domenatwo') . '</a></p>';
    echo '<br /><hr />';
    echo '<h4>' . __('API Data (For The Nerds)', 'domenatwo') .'</h4>';
    echo '<ul>';
    
    foreach($data['domains'] as $profile_id => $arDomainInfo) {
        echo '<li>' . $arDomainInfo['domainName'] . ' (' . $arDomainInfo['webPropertyID'] . ')</li>';
    }

    echo '</ul>';
}



/**
 * Render full admin page
 */ 
function google_analytics_admin_render_page(){
    if ( ! current_user_can('manage_options') ){
        google_analytics_admin_render_header( __("You don't have permission to manage Google Analytics API settings", 'domenatwo'), 'error');
        google_analytics_admin_render_footer();
        return;
    }

    $data = get_option('gai_data');

    try {
        if($data) {
            google_analytics_admin_render_header( __('Successfully authenticated to Google.', 'domenatwo'), 'updated' );
            google_analytics_admin_render_account_data($data);

        }else{
            throw new Exception('No token supplied');
        }

    } catch (Exception $e) {
        //token is not set or has expired
        google_analytics_admin_render_header( __('Not yet authenticated with Google. Login below.', 'domenatwo'), 'error' );
        google_analytics_admin_render_login();  
    }
    
    // end admin page with options form and close wrapper
    google_analytics_admin_render_footer();
}



function google_analytics_admin_styles($hook) {
    if( 'settings_page_ga-admin' != $hook )
        return;
    
    wp_enqueue_style( 'google-analytics-styles', get_template_directory_uri() . '/inc/google-analytics/ga-admin.css' );
}
add_action( 'admin_enqueue_scripts', 'google_analytics_admin_styles' );



/**
 * Admin menu registration callback
 */
function google_analytics_admin_menu() {
    add_options_page( __('Google Analytics', 'domenatwo'), __('Google Analytics', 'domenatwo'), 'manage_options', 'ga-admin', 'google_analytics_admin_render_page');
}

// register our admin page with the menu, and we're done.
add_action('admin_menu', 'google_analytics_admin_menu');