<?php

/**
 * ga.php
 *
 * Initializes Google Analytics, defines a few helper functions, and acts as a controller
 *
 * @author Andrew Kallemeyn <ak@ireed.net>
 */

require dirname(__FILE__) . '/ga-api.php';
require dirname(__FILE__) . '/ga-admin.php';
require dirname(__FILE__) . '/ga-core.php';

/**
 * Generate a chart, based on analytics data
 */
function ga_format_chart_url($chart_url, $color_scheme, $background_color, $width, $height) {
	$chart_url = str_replace('__WIDTH__', $width, $chart_url);
	$chart_url = str_replace('__HEIGHT__', $height, $chart_url);

	$axisColor = "333333";
	
	switch(strtolower($color_scheme)) {
		case "green":
			$lineColor = "669900";
			$boundaryFillColor = "e1efc3";
			break;

		case "red":
			$lineColor = "cc0000";
			$boundaryFillColor = "fadede";
			break;
		
		case "orange":
			$lineColor = "ff6600";
			$boundaryFillColor = "ffe0ca";
			break;
		
		case "blue":
		default:
			$lineColor = "33CCFF";
			$boundaryFillColor = "D1F2FC";			
	}

	if(strtolower($background_color) == "dark") {
		$axisColor = "cccccc";
		$boundaryFillColor = "2626269A";
	}

	$chart_url = str_replace('__LINECOLOR__', $lineColor, $chart_url);
	$chart_url = str_replace('__BOUNDARYFILLCOLOR__', $boundaryFillColor, $chart_url);
	$chart_url = str_replace('__AXISCOLOR__', $axisColor, $chart_url);
	
	return $chart_url;
}


/**
 * AJAX hook for getting latest analytics data
 */
function ga_ajax_return_data() {
	if(isset($_REQUEST['profileID']) && isset($_REQUEST['timePeriod'])) {	
		$ga = new GoogleAnalytics($_REQUEST['profileID']);
		
		//set time period
		$ga->set_time_period($_REQUEST['timePeriod']);

		$arLatestData = $ga->get_latest_data();
		$arLatestData['chart_url_large'] 	= ga_format_chart_url($arLatestData['chart_url'], $_REQUEST['colorSchemeElements'], $_REQUEST['colorSchemeMain'], '700', '100');
		$arLatestData['chart_url_medium'] 	= ga_format_chart_url($arLatestData['chart_url'], $_REQUEST['colorSchemeElements'], $_REQUEST['colorSchemeMain'], '540', '100');
		$arLatestData['chart_url_small'] 	= ga_format_chart_url($arLatestData['chart_url'], $_REQUEST['colorSchemeElements'], $_REQUEST['colorSchemeMain'], '300', '100');

		print(json_encode($arLatestData));
		exit;
	}
}



/**
 * Used to abbreviate numbers (1100 to 1.1k)
 */
function ga_abbrNum($value) {
	if($value == 0) 
		return 0;
	
    $abbreviations = array(12 => 't', 9 => 'b', 6 => 'm', 3 => 'k', 0 => '');

    foreach($abbreviations as $exponent => $abbreviation) {
        if($value >= pow(10, $exponent)) {
            return round(floatval($value / pow(10, $exponent)),1).$abbreviation;
        }
    }
}



/**
 * Process Google Analytics tokens (if available)
 */
if(current_user_can('administrator')) {
	try {
		$ga = new GoogleAnalytics();

		//process token from Google
		if(isset($_GET['token'])) {
			$ga->process_token($_GET['token'], admin_url('options-general.php?page=ga-admin'));
		}

		//destroy token
		if(isset($_GET['destroyToken'])) {
			if($ga->has_token() && $_GET['destroyToken'] == 1) {
				$ga->destroy_token();
			}
		}

	}catch(Exception $e) {
		print("<strong>Error:</strong> " . $e->getMessage());
		exit;
	}

	add_action('wp_ajax_ga_ajax_return_data', 'ga_ajax_return_data');
}