<?php
/**
 * Google Analytics admin functions
 * Configures and authenticates with the Google Analytics API
 * @author Andrew Kallemeyn <ak@vective.co>
 */
 
require dirname(__FILE__) . '/importer.php';

/**
 * Open admin page with header and message
 */
function importer_admin_render_header( $subheader, $css = '' ){
    ?>
     <div class="wrap">
        <h2><?php echo esc_html__('Domena One-Click Setup', 'domenatwo')?></h2>
        <div class="<?php echo $css?>">
            <h3><?php echo esc_html($subheader)?></h3>
        </div>
    <?php
} 



/**
 * Close admin page
 */
function importer_admin_render_footer(){
    ?>
    </div>
    <?php
}



/**
 * Render full admin page
 */ 
function importer_admin_render_page(){
    if ( ! current_user_can('import') ){
        importer_admin_render_header( __("You don't have permission to setup Domena.", 'domenatwo'), 'error');
        importer_admin_render_footer();
        return;
    }

    $setup_complete = get_option('domenatwo_demo_setup');

    if($setup_complete != "completed") {
        importer_admin_render_header( __('NOTE: This is only recommended for new websites. If you are installing Domena on an old website with existing data, please backup your data before proceeding.', 'domenatwo'), 'updated' );

    }else{
        importer_admin_render_header( __('WARNING: You have already imported our demo data. Importing the data again is not recommended.', 'domenatwo'), 'error' );
    }

    echo '<div id="one_click_setup_wrapper">';
        echo '<p>' . __("Import our demo content to setup your website automatically, which will give you a website that looks similar to our <a href=\"#\">live preview</a>. Once finished, you can customize the demo content for your needs, rather than starting from scratch.", 'domenatwo') . '</p>';
        echo '<a href="#" id="one_click_setup" class="button" title="Load Demo Data">' . __("Import Demo Content", 'domenatwo') . '</a>';
        echo '<span class="spinner"></span>';
        echo '<div class="import_result"></div>';
    echo '</div>';

    // end admin page with options form and close wrapper
    importer_admin_render_footer();
}



function importer_admin_styles($hook) {
    if( 'appearance_page_domena-one-click-setup' != $hook )
        return;

    wp_enqueue_script(
        'domenatwo-import-admin-js',
        get_template_directory_uri() . '/inc/importer/importer-admin.js',
        array( 'jquery' )
    );

    wp_enqueue_style(
        'domenatwo-import-admin-styles',
        get_template_directory_uri() . '/inc/importer/importer-admin.css'
    );
}
add_action( 'admin_enqueue_scripts', 'importer_admin_styles' );



/**
 * Setup demo content on theme setup / activation
 */
function ajax_setup_demo() {    
    $importer = new DomenaTwo_Importer();
    $importer->import();
    
    die();
}
add_action('wp_ajax_setup_demo', 'ajax_setup_demo', 20);



/**
 * Admin menu registration callback
 */
function importer_admin_menu() {
    add_theme_page( __('One-Click Setup', 'domenatwo'), __('One-Click Setup', 'domenatwo'), 'import', 'domena-one-click-setup', 'importer_admin_render_page');
}

// register our admin page with the menu, and we're done.
add_action('admin_menu', 'importer_admin_menu');