<?php

/**
 * Facilitates "1 click" setup of WP theme
 *
 * @package   Importer
 * @version   1.0
 * @author    Andrew Kallemeyn <ak@vective.co>
 * @copyright Copyright (c) 2013, Andrew Kallemeyn
 * @license   http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 *
 */

class DomenaTwo_Importer {
	private $content_xml = '/demo-data/demo-content.xml'; // posts, pages, nav
	private $widget_json = '/demo-data/demo-widgets.json'; // widgets

	public function __construct() {
		$this->content_xml = get_template_directory() . $this->content_xml;
		$this->widget_json = get_template_directory() . $this->widget_json;

		/**
		* Initialize Wordpress Importer
		* Even though this is a plugin, it needs to be manually initialized - ugh.
		*/
		$wp_importer_path = dirname( __FILE__ ) . '/wordpress-importer/wordpress-importer.php';

		if (file_exists($wp_importer_path)) {
			@include_once($wp_importer_path);

		}else{
			$this->response('error', "Please install the 'Wordpress Importer' plugin before installing the demo data.");
		}

		/**
		* Make sure "Widget Importer & Exporter" plugin is installed
		*/
		if(!function_exists('wie_import_data')) {
			$this->response('error', "Please install the 'Widget Importer & Exporter' plugin before installing the demo data.");			
		}
	}

	private function import_content() {
		if (class_exists('WP_Import')) {
			if(is_file($this->content_xml)) {
				$wp_import = new WP_Import();
				$wp_import->fetch_attachments = false;
				$wp_import->import( $this->content_xml );

			}else{
				$this->response('error', "The XML file containing the demo content is not available or could not be read: <pre>" . $this->content_xml . "</pre>");				
			}
		}else{
			$this->response('error', "Wordpress Importer not properly initialized.");
		}
	}

	private function import_menus() {
		/**
		* The menus were imported via import_content(), 
		* but we need to setup the menu locations
		*/

		$menus = get_terms('nav_menu');
		$save = array();

		foreach($menus as $menu){
			switch($menu->slug) {
				case 'footer':
					$save['footer'] = $menu->term_id;
			}
		}

		if($save){
		    set_theme_mod( 'nav_menu_locations', array_map( 'absint', $save ) );
		}
	}

	private function import_widgets() {
		if(is_file($this->widget_json)) {
			// Get file contents and decode
			$data = file_get_contents( $this->widget_json );
			$data = json_decode( $data );

			// Empty existing widget areas
			update_option("sidebars_widgets", array());

			// Import the widget data
			$wie_import_results = wie_import_data( $data );

		}else{
			$this->response('error', "The JSON file containing the demo content is not available or could not be read: <pre>" . $this->widget_json . "</pre>");							
		}
	}

	private function import_options() {
		//set reading options
		update_option("show_on_front", "page");

		//$blog = get_page_by_title('Blog');
		//update_option("page_for_posts", $blog->ID);

		$home = get_page_by_title('Demo Homepage');
		update_option("page_on_front", $home->ID);
	}

	public function import() {

		//import posts, pages, nav items
		//supress output
		ob_start();
		$result = $this->import_content();
		ob_end_clean();

		if(!is_wp_error($result)) {
			//content imported OK - continue with rest of import
			ob_start();

			//import widgets
			$this->import_widgets();

			//import menu locations
			$this->import_menus();

			//import options (like reading settings)
			$this->import_options();

			$data = ob_get_clean();

			if(strlen($data) == 0) {
				//set flag so we know the 1-click setup has been run
				update_option('domenatwo_demo_setup', "completed");

				$this->response('success');

			}else{
				//there was an error somewhere, hmm.
				$this->response('error', $data);
			}

		}else{
			$this->response('error',  $result->get_error_message());
		}
	}

	// ---- //

	private function response($status, $data='') {
		$response = json_encode(array('status' => $status, 'data' => $data));
		die ($response);
	}
}