<?php
/**
 * domenatwo Theme Options / Customizer
 *
 * @package domenatwo
 */

global $wp_customize;

// Theme Customizer Boilerplate
require get_template_directory() . '/inc/customizer-boilerplate/customizer.php';


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function domenatwo_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
}
add_action( 'customize_register', 'domenatwo_customize_register' );


/**
 * Add custom control for controlling parked domains
 */
function domenatwo_custom_controls() {
	class DomenaTwo_Parked_Domains_Control extends WP_Customize_Control {

		public $type = 'parked_domains';
		
		public function render_content() {
			$arDomains = array();
			$value = $this->value();

			if(!empty($value)) {
				$arDomains = explode("|", $value);
			}
		?>

		<div id="domenatwo-parked-domains">
			<ul class="domenatwo-parked-domains-list">
				<?php foreach($arDomains as $domain) : ?>
				<li><input type="text" value="<?php print($domain); ?>">&nbsp;&nbsp;<a href="#" class="delete-domain">Delete</a></li>
				<?php endforeach; ?>
			</ul>
			<input type="button" class="add-domain button-secondary" value="<?php _e( 'Add New', 'domenatwo' ) ?>" />
			<input type="hidden" id="<?php echo $this->id; ?>" class="parked-domains-list" <?php $this->link(); ?> value="<?php echo sanitize_text_field( $this->value() ); ?>">
		</div>

		<?php
		}

		public function enqueue() {
			wp_enqueue_style(
				'domenatwo_customizer_style',
				thsp_cbp_directory_uri() . '/customizer-controls.css'
			);

			wp_enqueue_script(
				'domenatwo_admin_customizer',
				get_template_directory_uri() . '/js/admin-customizer.js',
				array( 'jquery' )
			);
		}
	}
}
add_action( 'thsp_cbp_custom_controls', 'domenatwo_custom_controls' );


/**
 * Hooking into Theme Customizer Boilerplate to set name of DB entry
 * under which theme options are stored
 */
add_filter( 'thsp_cbp_option', 'domenatwo_edit_cbp_option_name', 1 );
function domenatwo_edit_cbp_option_name() {
    return 'domenatwo_options'; 
}


/**
 * Hooking into Theme Customizer Boilerplate to set Customizer location
 */
add_filter( 'thsp_cbp_directory_uri', 'domenatwo_edit_cbp_directory_uri', 1 );
function domenatwo_edit_cbp_directory_uri() {        
    return get_template_directory_uri() . '/inc/customizer-boilerplate';        
}


/**
 * Options array for Theme Customizer Boilerplate
 */
function domenatwo_options_array() {
	/*
	 * Using helper function to get default required capability
	 */
	$thsp_cbp_capability = thsp_cbp_capability();
	$default_parked_domain = $_SERVER['HTTP_HOST'];

	$options = array(
		// Domains
		'domain_settings' => array(
			'existing_section' => false,

			'args' => array(
				'title' => __( 'Parked Domains', 'domenatwo' ),
				'description' => __( 'The domains parked on your Wordpress installation.', 'domenatwo' ),
				'priority' => 1
			),
			
			'fields' => array(

				'domain_list' => array(

					'setting_args' => array(
						'default' => $default_parked_domain,
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					

					'control_args' => array(
						'type' => 'parked_domains'
					)
				)
			)
		),

		// Social Media
		'social_media_settings' => array(
			'existing_section' => false,

			'args' => array(
				'title' => __( 'Social Media', 'domenatwo' ),
				'description' => __( 'Add the URLs to your social networks.', 'domenatwo' ),
				'priority' => 2
			),
			
			'fields' => array(
				
				// Twitter
				'social_twitter' => array(

					'setting_args' => array(
						'default' => '',
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					

					'control_args' => array(
						'label' => __( 'Twitter', 'domenatwo' ),
						'type' => 'text'
					)
				),

				// Facebook
				'social_facebook' => array(

					'setting_args' => array(
						'default' => '',
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					

					'control_args' => array(
						'label' => __( 'Facebook', 'domenatwo' ),
						'type' => 'text'
					)
				),

				// Instagram
				'social_instagram' => array(

					'setting_args' => array(
						'default' => '',
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					

					'control_args' => array(
						'label' => __( 'Instagram', 'domenatwo' ),
						'type' => 'text'
					)
				),

				// YouTube
				'social_youtube' => array(

					'setting_args' => array(
						'default' => '',
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					

					'control_args' => array(
						'label' => __( 'YouTube', 'domenatwo' ),
						'type' => 'text'
					)
				)
			)
		),

		// Footer / Custom CSS
		'general_settings' => array(
			'existing_section' => false,

			'args' => array(
				'title' => __( 'Footer / Custom CSS', 'domenatwo' ),
				'priority' => 4
			),
			
			'fields' => array(
				
				// Footer
				'footer_text' => array(

					'setting_args' => array(
						'default' => __( '&copy; ' . date('Y', time()) . ' Domena Wordpress Theme', 'domenatwo' ),
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					

					'control_args' => array(
						'label' => __( 'Footer Text', 'domenatwo' ),
						'type' => 'text',
						'priority' => 1
					)
				),

				// Custom CSS
				'custom_css' => array(
					'setting_args' => array(
						'default' => '',
						'type' => 'option',
						'capability' => $thsp_cbp_capability,
						'transport' => 'postMessage'
					),					
					'control_args' => array(
						'label' => __( 'Custom CSS', 'domenatwo' ),
						'type' => 'textarea',
						'priority' => 2
					)
				)
			)
		)
	);
	
	/* 
	 * 'thsp_cbp_options_array' filter hook will allow you to 
	 * add/remove some of these options from a child theme
	 */
	return $options;
}
add_filter( 'thsp_cbp_options_array', 'domenatwo_options_array', 1 );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function domenatwo_customize_preview_js() {
	wp_enqueue_script( 'domenatwo_spin_js', get_template_directory_uri() . '/js/vendor/spin.min.js', array( 'customize-preview' ), '20130508', true );
	wp_enqueue_script( 'domenatwo_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'domenatwo_customize_preview_js' );


/**
 * Make AJAX URL accessible for saving settings
 */
function domenatwo_ajaxurl() {
	print("<script type=\"text/javascript\">var ajaxurl = '".admin_url('admin-ajax.php')."';</script>");
}

if ( isset( $wp_customize ) ) {
	add_action('wp_head','domenatwo_ajaxurl');
}


/**
 * Setup AJAX admin events for saving domain settings/config
 */
function domenatwo_save_domain_settings() {
	$config = domenatwo_get_all_domain_configs();

	foreach($config as $domain => $options) {
		if(!empty($_POST['data'][$domain])) {
			$config[$domain] = $_POST['data'][$domain];
		}
	}

	//clear analytics cache
	if(!empty($config[$domain]['gai_profile_id'])) {
		$ga = new GoogleAnalytics($config[$domain]['gai_profile_id']);
		$ga->clear_cache();
	}

	update_option('domenatwo_domain_config', $config);

	die();
}


/**
 * Setup AJAX event for getting page content
 */
function domenatwo_get_page_content() {
	if(empty($_POST['page_id'])) {
		$_POST['page_id'] = get_option('page_on_front');
	}

	if($_POST['page_id']) {
		$post_object = get_post($_POST['page_id']);
		print(do_shortcode(wpautop($post_object->post_content)));
		
	}else{
		print("ERROR_NO_FRONT_PAGE");
	}

	die();
}

if ( is_admin() ) {
	add_action( 'wp_ajax_get_page_content', 'domenatwo_get_page_content' );
	add_action( 'wp_ajax_save_domain_settings', 'domenatwo_save_domain_settings' );
}

$theme_options = thsp_cbp_get_options_values();