<?php

/**
* 
* Plugin Name: Latest Tweets
* Author: Andrew Kallemeyn <ak@vective.co>
* Forked from: https://github.com/timwhitlock/wp-twitter-api/blob/master/example-latest-tweets.php
*
*/

// bootstrap Twitter API Wordpress library
if( ! function_exists('twitter_api_get') ){
    require dirname(__FILE__).'/lib/twitter-api.php';
}



/**
 * Pull latest tweets with some caching of raw data.
 * @param string account whose tweets we're pulling
 * @param int number of tweets to get and display
 * @return array blocks of html expected by the widget
 */
function domena_latest_tweets_render( $screen_name, $count ) {
    if( function_exists('apc_fetch') ){
        // We could cache the rendered HTML, but this tests the twitter_api cache functions
        twitter_api_enable_cache( 300 );
    }

    try {
        // Note that excluding replies means we may get less than $count tweets.
        // So we'll get more than we want and trim the result.
        $tweets = twitter_api_get('statuses/user_timeline', array (
            'count' => 3 * $count,
            'exclude_replies' => true,
            'include_rts' => false,
            'trim_user' => true,
            'screen_name' => $screen_name,
        ) );
        if( isset($tweets[$count]) ){
            $tweets = array_slice( $tweets, 0, $count );
        }
    }
    catch( Exception $Ex ){
        return array( '<p><strong>Error:</strong> '.esc_html($Ex->getMessage()).'</p>' );
    }

    // render each tweet as a blocks of html for the widget list items
    twitter_api_include('utils');
    $rendered = array();
    foreach( $tweets as $tweet ){
        extract( $tweet );
        $link = esc_html( 'http://twitter.com/'.$screen_name.'/status/'.$id_str);
        $date = esc_html( twitter_api_relative_date($created_at) );
        
        $rendered[] = '<a class="tweet_date" href="'.$link.'" target="_blank"><time datetime="'.date("c", strtotime($created_at)).'">'.$date.'</time></a> - <span>'.twitter_api_html($text).'</span>';
    }

    return $rendered;
} 


 
  
/**
 * Example latest tweets widget class
 */
class Domena_Latest_Tweets_Widget extends WP_Widget {
    
    /** @see WP_Widget::__construct */
    public function __construct( $id_base = false, $name = 'Domena: Latest Tweets', $widget_options = array(), $control_options = array() ){
        $widget_options = array(
            'classname' => 'tweet_widget',
            'description' => __('A widget that displays your latest tweets.', 'domena')
        );

        $this->options = array(
            array (
                'name'  => 'title',
                'label' => __('Title', 'domena'),
                'type'  => 'text'
            ),
            array (
                'name'  => 'screen_name',
                'label' => __('Twitter handle', 'domena'),
                'type'  => 'text'
            ),
            array (
                'name'  => 'num',
                'label' => __('Number of tweets', 'domena'),
                'type'  => 'text'
            ),
        );
        parent::__construct( $id_base, __($name), $widget_options, $control_options );  
    }    
    
    /** @see WP_Widget::form */
    public function form( $instance ) {
        if ( empty($instance) ) {
            $instance['title']  = __('Latest Tweets', 'domena');
            $instance['screen_name'] = '';
            $instance['num'] = '3';
        }
        foreach ( $this->options as $val ) {
            $label = '<label for="'.$this->get_field_id($val['name']).'">'.$val['label'].'</label>';
            echo '<p>'.$label.'<br />';
            echo '<input class="widefat" id="'.$this->get_field_id($val['name']).'" name="'.$this->get_field_name($val['name']).'" type="text" value="'.esc_attr($instance[$val['name']]).'" /></p>';
        }
    }

    /** @see WP_Widget::widget */
    public function widget( $args, $instance ) {
        //make sure twitter API info is available
        $conf = array (
            'consumer_key'    => '',
            'consumer_secret' => '',
            'request_secret'  => '',
            'access_key'      => '',
            'access_secret'   => '',
        );

        foreach( $conf as $key => $val ){
            $conf[$key] = get_option('twitter_api_'.$key) or
            $conf[$key] = $val;
        }

        $title = $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        echo $args['before_widget'], $title, '<div class="latest-tweets">';

        if(array_filter($conf)) {
            echo '<ul>';
            foreach( domena_latest_tweets_render( $instance['screen_name'], $instance['num'] ) as $tweet ){
                echo '<li class="tweet">',$tweet,'</li>';
            }
            echo '</ul>';

            if(!empty($instance['screen_name'])) {
                echo '<a href="http://twitter.com/' . $instance['screen_name'] . '" class="follow_link">Follow @' . $instance['screen_name'] . '</a>';
            }
        }else{
            if(current_user_can( 'manage_options' )) {
                $url = admin_url('options-general.php?page=twitter-api-admin');
                echo '<p>Looking for your tweets? Configure the <a href="'. $url .'">Twitter API settings</a> and you will be ready to go!</p>';
            }else{
                echo '<p>';
                _e('Tweets Unavailable', 'domena');
                echo '</p>';               
            }
        }

        echo '</div>',$args['after_widget'];
    }
    
}

function domena_latest_tweets_register_widget(){
    return register_widget('Domena_Latest_Tweets_Widget');
}

add_action( 'widgets_init', 'domena_latest_tweets_register_widget' );