/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	"use strict";

	/**
	* Convert form values to JSON object
	* http://stackoverflow.com/questions/1184624/convert-form-data-to-js-object-with-jquery
	*/
	$.fn.serializeObject = function() {
	    var o = {};
	    var a = this.serializeArray();
	    $.each(a, function() {
	        if (o[this.name] !== undefined) {
	            if (!o[this.name].push) {
	                o[this.name] = [o[this.name]];
	            }
	            o[this.name].push(this.value || '');
	        } else {
	            o[this.name] = this.value || '';
	        }
	    });

	    return o;
	};

	/**
	 * jQuery alterClass plugin
	 *
	 * Remove element classes with wildcard matching. Optionally add classes:
	 *   $( '#foo' ).alterClass( 'foo-* bar-*', 'foobar' )
	 *
	 * Copyright (c) 2011 Pete Boere (the-echoplex.net)
	 * Free under terms of the MIT license: http://www.opensource.org/licenses/mit-license.php
	 *
	 */		
	$.fn.alterClass = function ( removals, additions ) {
		
		var self = this;
		
		if ( removals.indexOf( '*' ) === -1 ) {
			// Use native jQuery methods if there is no wildcard matching
			self.removeClass( removals );
			return !additions ? self : self.addClass( additions );
		}
	 
		var patt = new RegExp( '\\s' + 
				removals.
					replace( /\*/g, '[A-Za-z0-9-_]+' ).
					split( ' ' ).
					join( '\\s|\\s' ) + 
				'\\s', 'g' );
	 
		self.each( function ( i, it ) {
			var cn = ' ' + it.className + ' ';
			while ( patt.test( cn ) ) {
				cn = cn.replace( patt, ' ' );
			}
			it.className = $.trim( cn );
		});
	 
		return !additions ? self : self.addClass( additions );
	};

	var abbrNum = function(number, decPlaces) {
	    // 2 decimal places => 100, 3 => 1000, etc
	    decPlaces = Math.pow(10,decPlaces);

	    // Enumerate number abbreviations
	    var abbrev = [ "k", "m", "b", "t" ];

	    // Go through the array backwards, so we do the largest first
	    for (var i=abbrev.length-1; i>=0; i--) {

	        // Convert array index to "1000", "1000000", etc
	        var size = Math.pow(10,(i+1)*3);

	        // If the number is bigger or equal do the abbreviation
	        if(size <= number) {
	             // Here, we multiply by decPlaces, round, and then divide by decPlaces.
	             // This gives us nice rounding to a particular decimal place.
	             number = Math.round(number*decPlaces/size)/decPlaces;

	             // Handle special case where we round up to the next abbreviation
	             if((number == 1000) && (i < abbrev.length - 1)) {
	                 number = 1;
	                 i++;
	             }

	             // Add the letter for the abbreviation
	             number += abbrev[i];

	             // We are done... stop
	             break;
	        }
	    }

	    return number;
	}

	var $toolbar 		  = $('#customize-toolbar');
	var active_domain 	  = $.trim($toolbar.find('div.toolbar select[name="domains"] option:selected').text().toLowerCase());
	var _self;
	var config_loading	  = false;
	var updateChart 	  = null;
	var ajaxRequestActive = false;
	var current;

	var DomenaTwo_Customizer = {
		init: function () {
			_self = this;

			var hash = window.location.hash.replace('#', '');

			if($toolbar.length > 0) {

				var large_spinner = {
					lines: 15,
					length: 10,
					width: 2,
					radius: 19,
					className: 'spin'
				};

				var small_spinner = {
				  lines: 11,
				  length: 3,
				  width: 2,
				  radius: 4,
				  className: 'spin'
				};

				$( document ).ajaxStart(function() {
					if(config_loading) { //new domain config is loading
						ajaxRequestActive = true;
					}
				});

				$( document ).ajaxStop(function() {
					if(config_loading) { //new domain config is loading
						config_loading = false;
						ajaxRequestActive = false;
						_self.closeLoadingScreen();
					}
				});

				var large_spinner = new Spinner(large_spinner).spin($('#loading-screen div.spinner')[0]);
				var small_spinner = new Spinner(small_spinner).spin($toolbar.find('div.call-to-action div.spinner')[0]);

				this.setupEvents();
				this.initDomainConfig(active_domain);

				if(hash) {
					_self.openPanel('panel-' + hash);
				}
			}
		},

		setupEvents: function() {
			$toolbar.on('click', 'div.toolbar ul a', function(e) {
				e.preventDefault();

				//open tab
				if(!$(this).hasClass('active')) {
					_self.openPanel($(this).parent().attr('class'));

				//close tab
				}else{
					_self.closePanels();
				}
			});

			$toolbar.on('click', 'div.toolbar a.reload-page', function(e) {
				e.preventDefault();
				window.top.location.reload(true);
			});

			$toolbar.on('change', 'div.toolbar select', function(e) {
				var domain = $(this).find('option:selected').text();
				_self.initDomainConfig(domain);
			});

			$toolbar.on('submit', 'form', function(e) {
				e.preventDefault();

				var data = {
					action: 'save_domain_settings',
					data: domain_config
				};

				$toolbar.find('div.call-to-action div.spinner').show();

				$.post(ajaxurl, data, function(response) {
					$toolbar.find('div.call-to-action div.spinner').hide();
					_self.toggleSavedButton(true);
				});
			});

			$toolbar.on('click', 'button.secondary', function(e) {
				e.preventDefault();
				_self.closePanels();
			});

			$toolbar.on('keyup change', 'input, select', function(e) {
				var input_name = $(this).attr('name');
				var value = $(this).val();

				if(typeof(_self.updateCallbacks[input_name]) !== "undefined") {
					if(value !== null) {
						_self.updateCallbacks[input_name](value);
					}
				}
			});

			$toolbar.on('blur change', 'input, select', function(e) {
				//update JSON object
				var json = $toolbar.find('form').serializeObject();
				domain_config[active_domain] = json;
			});

			$toolbar.on('keyup change', 'input, select', function(e) {
				_self.toggleSavedButton(false);
			});

			$toolbar.on('click', 'div.ga-not-configured a, a.add-pages', function(e) {
				window.open(this.href,'_blank');
			});
		},

		initDomainConfig: function(domain) {
			var result = {};

			config_loading = true;

			_self.closePanels();

			$('body').addClass('loading');
			$('#loading-screen').show();

			$toolbar.find('input[name="domain_name"]').val(domain);

			$.each(domain_config, function(domain_key, config) {
				if(domain.toLowerCase() == domain_key) {
					result = config;
					active_domain = domain_key;
					return false;
				}
			});

			$.each(result, function(key, value) {
				$toolbar.find('input[name="' + key + '"]').val([value]);
				$toolbar.find('select[name="' + key + '"]').val([value]);

				//run callback function for this setting
				if(typeof(_self.updateCallbacks[key]) !== "undefined") {
					if(value !== null) {
						_self.updateCallbacks[key](value);
					}
				}
			});

			if(!ajaxRequestActive) {
				this.closeLoadingScreen();
			}		
		},

		openPanel: function(panel) {
			if(panel == "panel-google-analytics") {
				if($toolbar.find('div.ga-not-configured').length > 0) {
					$toolbar.find('div.call-to-action').hide();
				}

			}else{
				$toolbar.find('div.call-to-action').show();
			}

			//deactive previously clicked tabs
			$toolbar.find('div.toolbar ul a').removeClass();

			//activate clicked tab
			$toolbar.find('li.' + panel + ' a').addClass('active');

			//hide all panels
			$toolbar.find('div.panel').hide();

			//show clicked panel
			$('#' + panel).show().parent().show();
		},

		closePanels: function() {
			$toolbar.find('div.panels-container').hide();
			$toolbar.find('div.toolbar ul a').removeClass();			
		},

		updateChartPreview: function() {
			if($toolbar.find('div.ga-not-configured').length == 0) {
				var profileID  	= $toolbar.find('select[name="gai_profile_id"]').val();
				var timePeriod 	= $toolbar.find('select[name="gai_time_period"]').val();
				var colorSchemeElements = $toolbar.find('input[name="color_scheme_elements"]:checked').val();
				var colorSchemeMain = $toolbar.find('input[name="color_scheme_main"]:checked').val();

				if(profileID != "" && timePeriod != "") {
					//if a request to update the chart was previously sent, abort the request
					if(updateChart) {
						updateChart.abort();
					}

					updateChart = jQuery.ajax({
						url: ajaxurl,
						dataType: "json",
						type: "POST",
						cache: false,
						data: {action: 'ga_ajax_return_data', profileID: profileID, timePeriod: timePeriod, colorSchemeElements: colorSchemeElements, colorSchemeMain: colorSchemeMain},
						success: function(data) {
							_self.buildChartPreview(data);
						}
					});
				}
			}
		},

		toggleSavedButton: function(saved) {
			var $button = $toolbar.find('div.call-to-action button:first-child');
			
			if(saved) {
				$button.html('Saved').addClass('disabled');
			}else{
				$button.html('Save').removeClass('disabled');
			}
		},
		
		buildChartPreview: function(data) {
			var $stats = $('section.statistics');

			$stats.find('span.time-period').text(data.time_period);

			$stats.find('li.visits strong').text(abbrNum(data.visits, 1));
			$stats.find('li.unique-visits strong').text(abbrNum(data.unique_visits, 1));
			$stats.find('li.page-views strong').text(abbrNum(data.page_views, 1));
			$stats.find('li.new-visits-percentage strong').text(data.new_visits_percentage + '%');

			$stats.find('img.large').attr('src', data.chart_url_large);
			$stats.find('img.medium').attr('src', data.chart_url_medium);
			$stats.find('img.small').attr('src', data.chart_url_small);

			$stats.show();
		},

		closeLoadingScreen: function() {
			//close the loading screen that shows when loading domain configs
			$('body').removeClass('loading');
			$('#loading-screen').hide();
		},

		updateCallbacks: {
			page_title: function(value) {
				$('article h1.entry-title').text(value);
			},

			page_id: function(value) {
				var data = {
					action: 'get_page_content',
					page_id: value,
					active_domain: active_domain
				};

				$.post(ajaxurl, data, function(response) {
					if(response != "ERROR_NO_FRONT_PAGE") {
						$('article div.entry-content').html(response);
					}
				});
			},

			domain_name: function(value) {
				$('header.masthead h1 a').text(value);
			},

			color_scheme_elements: function(value) {
				var color = value.toLowerCase();

				$('body').alterClass('color-scheme-elements-*', 'color-scheme-elements-' + color);

				if(!config_loading) {
					_self.updateChartPreview();
				}
			},

			color_scheme_main: function(value) {
				var color = value.toLowerCase();

				$('body').alterClass('color-scheme-main-*', 'color-scheme-main-' + color);

				if(!config_loading) {
					_self.updateChartPreview();
				}
			},

			price_original: function(value) {
				var $price = $('section.call-to-action span.price');

				if(value != "") {
					$price.text(value).show();

				}else{
					$price.hide();
				}				
			},

			price_discount: function(value) {
				var $price = $('section.call-to-action span.price-discounted');

				if(value != "") {
					$price.text(value).show();

				}else{
					$price.hide();
				}
			},

			price_button_text: function(value) {
				var $button = $('section.call-to-action a.primary');

				if(value != "") {
					$button.find('span.text').text(value);
					$button.show();

				}else{
					$button.hide();
				}
			},

			price_button_link: function(value) {
				$('section.call-to-action a.button.primary').attr('href', value);
			},

			offer_button_text: function(value) {
				$('section.call-to-action a.button.secondary').text(value);
			},

			offer_button_link: function(value) {
				$('section.call-to-action a.button.secondary').attr('href', value);
			},

			gai_profile_id: function(value) {
				_self.updateChartPreview();

				if(value == "") {
					$toolbar.find('li.gai-time-period-label').hide();
					$('section.statistics').hide();

				}else{
					$toolbar.find('li.gai-time-period-label').show();
				}
			},

			gai_time_period: function(value) {
				_self.updateChartPreview();
			}
		},

		updateSocialMedia: function() {
			var social = {
				twitter: wp.customize.instance( 'domenatwo_options[social_twitter]').get(),
				facebook: wp.customize.instance( 'domenatwo_options[social_facebook]').get(),
				instagram: wp.customize.instance( 'domenatwo_options[social_instagram]').get(),
				youtube: wp.customize.instance( 'domenatwo_options[social_youtube]').get()
			}

			if($('footer ul.social').length > 0) {
				$('footer ul.social').remove();
			}

			//build social menu
			$('footer div.inner').prepend('<ul class="social"></ul>');

			$.each(social, function(key, url) {
				if(url != '') {
					$('footer ul.social').append('<li class="' + key +'"><a href="' + url + '"><span class="fa fa-' + key + '"></span></a></li>');
				}
			});
		}
	}

	DomenaTwo_Customizer.init();

	// Parked Domains
	wp.customize( 'domenatwo_options[domain_list]', function( value ) {
		value.bind( function( to ) {
			$toolbar.find('div.toolbar a.reload-page').show();
		} );
	} );

	// Social Media
	wp.customize( 'domenatwo_options[social_twitter]', function( value ) {
		value.bind( function( to ) {
			DomenaTwo_Customizer.updateSocialMedia();
		} );
	} );

	wp.customize( 'domenatwo_options[social_facebook]', function( value ) {
		value.bind( function( to ) {
			DomenaTwo_Customizer.updateSocialMedia();
		} );
	} );

	wp.customize( 'domenatwo_options[social_instagram]', function( value ) {
		value.bind( function( to ) {
			DomenaTwo_Customizer.updateSocialMedia();
		} );
	} );

	wp.customize( 'domenatwo_options[social_youtube]', function( value ) {
		value.bind( function( to ) {
			DomenaTwo_Customizer.updateSocialMedia();
		} );
	} );

	// Footer Text
	wp.customize( 'domenatwo_options[footer_text]', function( value ) {
		value.bind( function( to ) {
			$( 'footer p.footer-text' ).text( to );
		} );
	} );

	// Custom CSS
	wp.customize( 'domenatwo_options[custom_css]', function( value ) {
		value.bind( function( to ) {
			$( '#custom_css' ).remove();
			$( 'head' ).append('<style type="text/css" id="custom_css">' + to + '</style>');
		} );
	} );

} )( jQuery );