/**
* demo-live-preview.js
* Initializes the Live Preview toolbar and handles switching between demos
*
*/

(function($) {
	"use strict";

	/**
	 * jQuery alterClass plugin
	 *
	 * Remove element classes with wildcard matching. Optionally add classes:
	 *   $( '#foo' ).alterClass( 'foo-* bar-*', 'foobar' )
	 *
	 * Copyright (c) 2011 Pete Boere (the-echoplex.net)
	 * Free under terms of the MIT license: http://www.opensource.org/licenses/mit-license.php
	 *
	 */		
	$.fn.alterClass = function ( removals, additions ) {
		
		var self = this;
		
		if ( removals.indexOf( '*' ) === -1 ) {
			// Use native jQuery methods if there is no wildcard matching
			self.removeClass( removals );
			return !additions ? self : self.addClass( additions );
		}
	 
		var patt = new RegExp( '\\s' + 
				removals.
					replace( /\*/g, '[A-Za-z0-9-_]+' ).
					split( ' ' ).
					join( '\\s|\\s' ) + 
				'\\s', 'g' );
	 
		self.each( function ( i, it ) {
			var cn = ' ' + it.className + ' ';
			while ( patt.test( cn ) ) {
				cn = cn.replace( patt, ' ' );
			}
			it.className = $.trim( cn );
		});
	 
		return !additions ? self : self.addClass( additions );
	};

	var livePreview = {
		init: function(defaultDemoKey) {
			$('body').append($('#live-preview-toolbar-view').val()).addClass('demo_live_preview');
			this.$toolbar = $('#live-preview-toolbar');
			this.currentElementsColorScheme = 'blue';
			this.currentMainColorScheme = 'light';

			//if the browser supports media queries...
			if(Modernizr.mq('only all')) {
				this.$toolbar.find('.message').show();
			}

			//setup events
			this.$toolbar.find('ul.color_options li a').click(function(e) {
				if(!$(this).parent().hasClass('selected')) {
					var colorScheme = $(this).parent().attr('class');
					livePreview.changeAccentColor(colorScheme);
				}
		
				return false;
			});

			this.$toolbar.find('select.demo_options').bind('change', function(e) {
				livePreview.changeColorScheme($(this).val());
			});
		},
		
		changeColorScheme: function(scheme) {
			this.currentMainColorScheme = scheme;

			$('body').alterClass('color-scheme-main-*', 'color-scheme-main-' + scheme);
			this.updateChartPreview();
		},
		
		changeAccentColor: function(color) {
			if(typeof(this.$toolbar) != 'undefined') {
				this.$toolbar.find('ul.color_options li').removeClass('selected');
				this.$toolbar.find('ul.color_options li.' + color).addClass('selected');
			}

			this.currentElementsColorScheme = color;

			$('body').alterClass('color-scheme-elements-*', 'color-scheme-elements-' + color);
			this.updateChartPreview();
		},

		updateChartPreview: function() {
			if(typeof(chartURL) != 'undefined') {
				var color_scheme	 = this.currentElementsColorScheme;
				var background_color = this.currentMainColorScheme;
        		var chart_url_large  = ga_format_chart_url(chartURL, color_scheme, background_color, 700, 100);
        		var chart_url_medium = ga_format_chart_url(chartURL, color_scheme, background_color, 540, 100);
        		var chart_url_small  = ga_format_chart_url(chartURL, color_scheme, background_color, 300, 100);

				$('section.statistics img.large').attr('src', chart_url_large);
				$('section.statistics img.medium').attr('src', chart_url_medium);
				$('section.statistics img.small').attr('src', chart_url_small);
			}
		}
	}

	$(document).ready(function() {
		livePreview.init();
	});

})(jQuery);

//utility function to help format the chart URL based on the color scheme
function ga_format_chart_url(chart_url, color_scheme, background_color, width, height) {
	chart_url = chart_url.replace('__WIDTH__', width);
	chart_url = chart_url.replace('__HEIGHT__', height);

	var axisColor = "333333";
	
	switch(color_scheme.toLowerCase()) {
		case "green":
			var lineColor = "669900";
			var boundaryFillColor = "e1efc3";
			break;

		case "red":
			var lineColor = "cc0000";
			var boundaryFillColor = "fadede";
			break;
		
		case "orange":
			var lineColor = "ff6600";
			var boundaryFillColor = "ffe0ca";
			break;
		
		case "blue":
		default:
			var lineColor = "33CCFF";
			var boundaryFillColor = "D1F2FC";			
	}

	if(background_color.toLowerCase() == "dark") {
	 	axisColor = "cccccc";
		boundaryFillColor = "2626269A";
	}

	chart_url = chart_url.replace(/__LINECOLOR__/g, lineColor);
	chart_url = chart_url.replace(/__BOUNDARYFILLCOLOR__/g, boundaryFillColor);
	chart_url = chart_url.replace(/__AXISCOLOR__/g, axisColor);

	return chart_url;
}